==> landers.angular-2.0.77.tgz: package/src/main/api.js <==
;angular.module('Landers.angular')
    .factory('AngularApi', ['$httpParamSerializer', 'Ajax', function ($httpParamSerializer, Ajax) {
        var url_styles = {
            restful : {
                index: '{apiurl}?page={page}&pagesize={pagesize}',
                create: '{apiurl}/create',
                store: '{apiurl}',
                show: '{apiurl}/{id}',
                edit: '{apiurl}/{id}/edit',
                update: '{apiurl}/{id}',
                delete: '{apiurl}/{id}',
                opposite: '{apiurl}/opposite/{id}/{prop}',
                custom : '{apiurl}/{action}'
            },
            parallelism : {
                index: '{apiurl}/list?page={page}&pagesize={pagesize}',
                create: '{apiurl}/create',
                store: '{apiurl}/create',
                show: '{apiurl}/show?id={id}',
                edit: '{apiurl}/edit?id={id}',
                update: '{apiurl}/update?id={id}',
                delete: '{apiurl}/delete?id={id}',
                custom: '{apiurl}/{action}'
            },
            lwap : {
                index: '{apiurl}?act=_loadlist_&page={page}&pagesize={pagesize}',
                store: '{apiurl}?act=_create_',
                show: '{apiurl}?act=_show_&id={id}',
                edit: '{apiurl}?act=_loadedit_&id={id}',
                update: '{apiurl}?act=_modify_&id={id}',
                delete: '{apiurl}?act=_delete_&id={id}',
                opposite : '{apiurl}?act=_opposite_&id={id}&field={field}',
                custom: '{apiurl}?act={action}'
            }
        };

        function Api(config) {//api_url, url_style, url_params, ajax
            var that = this;
            var ajax = config.ajax || Ajax.make();
            this.config = function(){
                if (arguments.length) {
                    var arg0 = arguments[0];
                    if ( typeof(arg0) == 'string' ) {
                        return config[arg0];
                    } else {
                        config = arguments[0];
                    }
                } else {
                    return config;
                }
            },
            this.debug = function(){
                ajax.debug();
                return this;
            },
            this.buildUrl = function(action, params) {
                var replaces = angular.extend({}, params);
                replaces['apiurl'] = config.api_url;
                replaces['params'] = (function(){
                    var params = angular.extend({}, params || {}, config.url_params || {});
                    return $httpParamSerializer(params);
                })();
                var apiurl = url_styles[config.url_style][action];
                var link = apiurl.indexOf('?') > 0 ? '&' : '?';

                if (replaces['params']) apiurl += link + '{params}';
                for (var k in replaces) {
                    apiurl = apiurl.replace('{' + k + '}', replaces[k]);
                }
                return apiurl;
            },
            this.loading = function(is){
                ajax.loading(is);
                return this;
            },
            this.show = function(id, params){
                var url = this.buildUrl('show', {id:id});
                return ajax.get(url, params);
            },
            this.list = function(page, params, pagesize){
                var url = this.buildUrl('index', {page:page || 1, pagesize: pagesize ||''});
                return ajax.get(url, params);
            },
            this.edit = function(dat_id, params){
                var url = this.buildUrl('edit', {id:dat_id});
                return ajax.get(url, params);
            },
            this.create = function(data, params){
                var url = this.buildUrl('store');
                return ajax.post(url, data, params);
            },
            this.update = function(dat_id, data, params){
                var url = this.buildUrl('update', {id:dat_id});
                if ( config.url_style == 'restful' ) {
                    return ajax.put(url, data, params);
                } else {
                    return ajax.post(url, data, params);
                }
            },
            this.delete = function(dat_ids, params){
                if (angular.isArray(dat_ids)) dat_ids = dat_ids.join(',');
                var url = this.buildUrl('delete', {id:dat_ids});
                if ( config.url_style == 'restful' ) {
                    return ajax.delete(url, params);
                } else {
                    return ajax.post(url, params);
                }
            },
            this.opposite = function(dat_id, prop) {
                var url = this.buildUrl('opposite', {id:dat_id, prop:prop});
                return ajax.get(url);
            },
            this.get = function(action, params) {
                var url = this.buildUrl('custom', {action:action});
                return ajax.get(url, params);
            },
            this.post = function(action, data, params) {
                var url = this.buildUrl('custom', {action:action});
                return ajax.post(url, data, params);
            };
        }

        return {
            make : function(config){
                return new Api(config);
            }
        };
    }]);

==> landers.angular-2.0.81.tgz: package/src/main/api.js <==
;angular.module('Landers.angular')
    .factory('AngularApi', ['$httpParamSerializer', 'Ajax', function ($httpParamSerializer, Ajax) {
        var url_styles = {
            restful : {
                index: '{apiurl}?page={page}&pagesize={pagesize}',
                create: '{apiurl}/create',
                store: '{apiurl}',
                show: '{apiurl}/{id}',
                edit: '{apiurl}/{id}/edit',
                update: '{apiurl}/{id}',
                delete: '{apiurl}/{id}',
                opposite: '{apiurl}/opposite/{id}/{prop}',
                custom : '{apiurl}/{action}'
            },
            parallelism : {
                index: '{apiurl}/list?page={page}&pagesize={pagesize}',
                create: '{apiurl}/create',
                store: '{apiurl}/create',
                show: '{apiurl}/show?id={id}',
                edit: '{apiurl}/edit?id={id}',
                update: '{apiurl}/update?id={id}',
                delete: '{apiurl}/delete?id={id}',
                custom: '{apiurl}/{action}'
            },
            lwap : {
                index: '{apiurl}?act=_loadlist_&page={page}&pagesize={pagesize}',
                store: '{apiurl}?act=_create_',
                show: '{apiurl}?act=_show_&id={id}',
                edit: '{apiurl}?act=_loadedit_&id={id}',
                update: '{apiurl}?act=_modify_&id={id}',
                delete: '{apiurl}?act=_delete_&id={id}',
                opposite : '{apiurl}?act=_opposite_&id={id}&field={field}',
                custom: '{apiurl}?act={action}'
            }
        };

        function Api(config) {//api_url, url_style, url_params, ajax
            var that = this;
            var ajax = config.ajax || Ajax.make();
            this.config = function(){
                if (arguments.length) {
                    var arg0 = arguments[0];
                    if ( typeof(arg0) == 'string' ) {
                        return config[arg0];
                    } else {
                        config = arguments[0];
                    }
                } else {
                    return config;
                }
            },
            this.debug = function(){
                ajax.debug();
                return this;
            },
            this.buildUrl = function(action, params) {
                var replaces = angular.extend({}, params);
                replaces['apiurl'] = config.api_url;
                replaces['params'] = (function(){
                    var params = angular.extend({}, params || {}, config.url_params || {});
                    return $httpParamSerializer(params);
                })();
                var apiurl = url_styles[config.url_style][action];
                var link = apiurl.indexOf('?') > 0 ? '&' : '?';

                if (replaces['params']) apiurl += link + '{params}';
                for (var k in replaces) {
                    apiurl = apiurl.replace('{' + k + '}', replaces[k]);
                }
                return apiurl;
            },
            this.loading = function(is){
                ajax.loading(is);
                return this;
            },
            this.show = function(id, params){
                var url = this.buildUrl('show', {id:id});
                return ajax.get(url, params);
            },
            this.list = function(page, params, pagesize){
                var url = this.buildUrl('index', {page:page || 1, pagesize: pagesize ||''});
                return ajax.get(url, params);
            },
            this.edit = function(dat_id, params){
                var url = this.buildUrl('edit', {id:dat_id});
                return ajax.get(url, params);
            },
            this.create = function(data, params){
                var url = this.buildUrl('store');
                return ajax.post(url, data, params);
            },
            this.update = function(dat_id, data, params){
                var url = this.buildUrl('update', {id:dat_id});
                if ( config.url_style == 'restful' ) {
                    return ajax.put(url, data, params);
                } else {
                    return ajax.post(url, data, params);
                }
            },
            this.delete = function(dat_ids, params){
                params = params || {};
                if (angular.isArray(dat_ids)) {
                    // 批量删除
                    params.ids = dat_ids.join(',');
                    var url = this.buildUrl('custom', {action:'deletes'});
                    return ajax.post(url, params);
                } else {
                    // 删除单个
                    var url = this.buildUrl('delete', {id:dat_ids});
                    if ( config.url_style == 'restful' ) {
                        return ajax.delete(url, params);
                    } else {
                        return ajax.post(url, params);
                    }
                }
            },
            this.opposite = function(dat_id, prop) {
                var url = this.buildUrl('opposite', {id:dat_id, prop:prop});
                return ajax.get(url);
            },
            this.get = function(action, params) {
                var url = this.buildUrl('custom', {action:action});
                return ajax.get(url, params);
            },
            this.post = function(action, data, params) {
                var url = this.buildUrl('custom', {action:action});
                return ajax.post(url, data, params);
            };
        }

        return {
            make : function(config){
                return new Api(config);
            }
        };
    }]);
